==> eam-wshub-proxyclient-11.4-11-sources.jar: net/datastream/schemas/mp_fields/LOOKUPDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour LOOKUPDETAILS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="LOOKUPDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SQLCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUERYCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOVATTACHED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NOTAVAILABLE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OVERRIDE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VALIDATEFILE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOVENTITYID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LOOKUPDETAILS_Type", propOrder = {
    "sqlcode",
    "querycode",
    "lovattached",
    "notavailable",
    "override",
    "validatefile",
    "loventityid"
})
public class LOOKUPDETAILS_Type {

    @XmlElement(name = "SQLCODE")
    protected String sqlcode;
    @XmlElement(name = "QUERYCODE")
    protected String querycode;
    @XmlElement(name = "LOVATTACHED")
    protected String lovattached;
    @XmlElement(name = "NOTAVAILABLE")
    protected String notavailable;
    @XmlElement(name = "OVERRIDE")
    protected String override;
    @XmlElement(name = "VALIDATEFILE")
    protected String validatefile;
    @XmlElement(name = "LOVENTITYID")
    protected LOVENTITYID loventityid;

    /**
     * Obtient la valeur de la propriété sqlcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSQLCODE() {
        return sqlcode;
    }

    /**
     * Définit la valeur de la propriété sqlcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSQLCODE(String value) {
        this.sqlcode = value;
    }

    /**
     * Obtient la valeur de la propriété querycode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getQUERYCODE() {
        return querycode;
    }

    /**
     * Définit la valeur de la propriété querycode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setQUERYCODE(String value) {
        this.querycode = value;
    }

    /**
     * Obtient la valeur de la propriété lovattached.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOVATTACHED() {
        return lovattached;
    }

    /**
     * Définit la valeur de la propriété lovattached.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOVATTACHED(String value) {
        this.lovattached = value;
    }

    /**
     * Obtient la valeur de la propriété notavailable.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNOTAVAILABLE() {
        return notavailable;
    }

    /**
     * Définit la valeur de la propriété notavailable.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNOTAVAILABLE(String value) {
        this.notavailable = value;
    }

    /**
     * Obtient la valeur de la propriété override.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOVERRIDE() {
        return override;
    }

    /**
     * Définit la valeur de la propriété override.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOVERRIDE(String value) {
        this.override = value;
    }

    /**
     * Obtient la valeur de la propriété validatefile.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVALIDATEFILE() {
        return validatefile;
    }

    /**
     * Définit la valeur de la propriété validatefile.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVALIDATEFILE(String value) {
        this.validatefile = value;
    }

    /**
     * Obtient la valeur de la propriété loventityid.
     * 
     * @return
     *     possible object is
     *     {@link LOVENTITYID }
     *     
     */
    public LOVENTITYID getLOVENTITYID() {
        return loventityid;
    }

    /**
     * Définit la valeur de la propriété loventityid.
     * 
     * @param value
     *     allowed object is
     *     {@link LOVENTITYID }
     *     
     */
    public void setLOVENTITYID(LOVENTITYID value) {
        this.loventityid = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/LOOKUPDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for LOOKUPDETAILS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="LOOKUPDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SQLCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUERYCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOVATTACHED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NOTAVAILABLE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OVERRIDE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VALIDATEFILE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOVENTITYID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LOOKUPDETAILS_Type", propOrder = {
    "sqlcode",
    "querycode",
    "lovattached",
    "notavailable",
    "override",
    "validatefile",
    "loventityid"
})
public class LOOKUPDETAILS_Type {

    @XmlElement(name = "SQLCODE")
    protected String sqlcode;
    @XmlElement(name = "QUERYCODE")
    protected String querycode;
    @XmlElement(name = "LOVATTACHED")
    protected String lovattached;
    @XmlElement(name = "NOTAVAILABLE")
    protected String notavailable;
    @XmlElement(name = "OVERRIDE")
    protected String override;
    @XmlElement(name = "VALIDATEFILE")
    protected String validatefile;
    @XmlElement(name = "LOVENTITYID")
    protected LOVENTITYID loventityid;

    /**
     * Gets the value of the sqlcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSQLCODE() {
        return sqlcode;
    }

    /**
     * Sets the value of the sqlcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSQLCODE(String value) {
        this.sqlcode = value;
    }

    /**
     * Gets the value of the querycode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getQUERYCODE() {
        return querycode;
    }

    /**
     * Sets the value of the querycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setQUERYCODE(String value) {
        this.querycode = value;
    }

    /**
     * Gets the value of the lovattached property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOVATTACHED() {
        return lovattached;
    }

    /**
     * Sets the value of the lovattached property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOVATTACHED(String value) {
        this.lovattached = value;
    }

    /**
     * Gets the value of the notavailable property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNOTAVAILABLE() {
        return notavailable;
    }

    /**
     * Sets the value of the notavailable property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNOTAVAILABLE(String value) {
        this.notavailable = value;
    }

    /**
     * Gets the value of the override property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOVERRIDE() {
        return override;
    }

    /**
     * Sets the value of the override property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOVERRIDE(String value) {
        this.override = value;
    }

    /**
     * Gets the value of the validatefile property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVALIDATEFILE() {
        return validatefile;
    }

    /**
     * Sets the value of the validatefile property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVALIDATEFILE(String value) {
        this.validatefile = value;
    }

    /**
     * Gets the value of the loventityid property.
     * 
     * @return
     *     possible object is
     *     {@link LOVENTITYID }
     *     
     */
    public LOVENTITYID getLOVENTITYID() {
        return loventityid;
    }

    /**
     * Sets the value of the loventityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOVENTITYID }
     *     
     */
    public void setLOVENTITYID(LOVENTITYID value) {
        this.loventityid = value;
    }

}
